==> wdng-1.0.44.tgz: package/template/project/webpack.base.cofig.js <==
import ExtractTextPlugin from 'extract-text-webpack-plugin'
import HtmlWebpackPlugin from 'html-webpack-plugin'
import path from 'path'
import Config from './config/config.local'
import webpack from 'webpack'
export default (env, testNum) => {
    let config = new Config(env, testNum)
    let outputName = {
        path: path.resolve(__dirname, config.build_base_dir + config.module_id),
        jsName: '[name].bundle.js',
        cssName: '[name].css',
        htmlName: 'index.html'
    }
    let htmlConfig = {
        html5: true,
        minifyURLs: true,
        removeTagWhitespace: true,
        removeComments: true,
        removeEmptyElements: false,
        collapseWhitespace: false
    }

    //正式环境需要带md5序列，html与cdn资源分开
    if (env == 'production') {
        outputName.path = path.resolve(__dirname, config.build_base_dir + 'cdn/' + config.module_id)
        outputName.jsName = '[name].bundle.[hash:8].js'
        outputName.cssName = '[name].[hash:8].css'
        outputName.htmlName = `../../../html/${config.module_id}/index.html`
        htmlConfig.collapseWhitespace = true
        htmlConfig.removeEmptyElements = true
    }
    return {
        baseConfig: config,
        webpackConfig: {
            //页面入口文件配置
            entry: {
                vendor: './src/vendor',
                entry: './src/entry.js'
            },
            //入口文件输出配置
            output: {
                filename: outputName.jsName,
                path: outputName.path,
                publicPath: './'
            },
            module: {
                //加载器配置
                loaders: [{
                    test: /\.js|\.php|\.html$/,
                    loader: 'string-replace-loader',
                    query: {
                        multiple: config.replace
                    },
                }, {
                    test: /\.scss$/,
                    use: ExtractTextPlugin.extract({
                        fallback: 'style-loader',
                        use: ['css-loader?{minimize:true}', {
                            loader: 'postcss-loader',
                            options: {
                                plugins: [
                                    require('autoprefixer')('>0.1%')
                                ]
                            }
                        }, 'sass-loader?includePaths[]=./node_modules']
                    }),
                }, {
                    test: /\.js$/,
                    exclude: /node_modules/,
                    use: ['babel-loader'],
                    enforce: 'pre'
                }, {
                    test: /\.(png|jpg|jpeg|gif)$/,
                    use: ['url-loader?limit=10&name=/images/[name].[hash:8].[ext]'],
                }, {
                    test: /\.php|\.html$/,
                    use: ['html-loader'],
                }]
            },
            //插件项
            plugins: [
                new ExtractTextPlugin({
                    filename: outputName.cssName,
                    disable: false,
                    allChunks: true
                }),
                new HtmlWebpackPlugin({
                    filename: outputName.htmlName,
                    template: config.entry_html,
                    minify: htmlConfig,
                    inject: 'body'
                }),
                new webpack.optimize.CommonsChunkPlugin({
                    names: ['vendor'],
                    minChunks: Infinity
                })
            ],
            resolve: {
                //自动扩展文件后缀名，意味着我们require模块可以省略不写后缀名
                extensions: ['.js', '.json', '.scss'],
            }

        }
    }
}

==> wdng-1.1.0.tgz: package/template/project/webpack.base.cofig.js <==
import ExtractTextPlugin from 'extract-text-webpack-plugin'
import HtmlWebpackPlugin from 'html-webpack-plugin'
import Config from './config/config.local'
import path from 'path'
import webpack from 'webpack'
export default (env, testNum) => {
    let config = new Config(env, testNum)
    return {
        baseConfig: config,
        webpackConfig: {
            //é¡µé¢å¥å£æä»¶éç½®
            entry: {
                vendor: './src/vendor',
                entry: './src/entry.js'
            },
            //å¥å£æä»¶è¾åºéç½®
            output: {
                filename: config.outputName.jsName,
                path: config.outputName.path,
                publicPath: './'
            },
            module: {
                //å è½½å¨éç½®
                loaders: [{
                    test: /\.js|\.php|\.html$/,
                    exclude: path.resolve(__dirname,config.entryHtml),                     
                    loader: 'string-replace-loader',
                    query: {
                        multiple: config.replace
                    },
                }, {
                    test: /\.scss$/,
                    use: ExtractTextPlugin.extract({
                        fallback: 'style-loader',
                        use: ['css-loader?{minimize:true}', {
                            loader: 'postcss-loader',
                            options: {
                                plugins: [
                                    require('autoprefixer')('>0.1%')
                                ]
                            }
                        }, 'sass-loader?includePaths[]=./node_modules']
                    }),
                }, {
                    test: /\.js$/,
                    exclude: /node_modules/,
                    use: ['babel-loader'],
                    enforce: 'pre'
                }, {
                    test: /\.(png|jpg|jpeg|gif)$/,
                    use: ['url-loader?limit=10&name=/images/[name].[hash:8].[ext]'],
                }, {
                    test : /\.json$/,
                    use : ['json-loader']
                },{
                    test: /\.php|\.html$/,
                    exclude: path.resolve(__dirname,config.entryHtml),                                         
                    use: ['html-loader'],
                }]
            },
            //æä»¶é¡¹
            plugins: [
                new ExtractTextPlugin({
                    filename: config.outputName.cssName,
                    disable: false,
                    allChunks: true
                }),
                new HtmlWebpackPlugin({
                    filename: config.outputName.htmlName,
                    template: config.entryHtml,
                    minify: config.htmlConfig,
                    inject: 'body'
                }),
                new webpack.optimize.CommonsChunkPlugin({
                    names: ['vendor'],
                    minChunks: Infinity
                })
            ],
            resolve: {
                //èªå¨æ©å±æä»¶åç¼åï¼æå³çæä»¬requireæ¨¡åå¯ä»¥çç¥ä¸ååç¼å
                extensions: ['.js', '.json', '.scss'],
            }

        }
    }
}
